@@ -45,16 +45,16 @@ class PropertiesBrowserModel: public QAbstractItemModel
 public:
     PropertiesBrowserModel(WorldModel* worldModel, QObject* parent = 0);
 
-    QVariant data(const QModelIndex &index, int role) const;
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
-    QModelIndex parent(const QModelIndex &index) const;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const;
+    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
     QVariant headerData(int section, Qt::Orientation orientation,
-                         int role = Qt::DisplayRole) const;
+                         int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-    Qt::ItemFlags flags(const QModelIndex &index) const;
-    bool setData(const QModelIndex &index, const QVariant &value, int role);
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    bool setData(const QModelIndex &index, const QVariant &value, int role) Q_DECL_OVERRIDE;
 
     void setObject(StepCore::Object* object);
     StepCore::Object* object() { return _object; }
@@ -89,6 +89,7 @@ PropertiesBrowserModel::PropertiesBrowserModel(WorldModel* worldModel, QObject*
 
 void PropertiesBrowserModel::setObject(StepCore::Object* object)
 {
+    beginResetModel();
     _object = object;
 
     _subRows.clear();
@@ -111,7 +112,7 @@ void PropertiesBrowserModel::setObject(StepCore::Object* object)
         }
     }
 
-    reset();
+    endResetModel();
 }
 
 void PropertiesBrowserModel::emitDataChanged(bool dynamicOnly)
@@ -272,11 +273,12 @@ bool PropertiesBrowserModel::setData(const QModelIndex &index, const QVariant &v
             }
             if(index.row() == 1 && dynamic_cast<StepCore::Solver*>(_object)) {
                 if(value.toString() != _object->metaObject()->className()) {
+                    beginResetModel();
                     _worldModel->beginMacro(i18n("Change solver type"));
                     _object = _worldModel->newSolver(value.toString() + "Solver");
                     Q_ASSERT(_object != NULL);
                     _worldModel->endMacro();
-                    reset();
+                    endResetModel();
                 }
             } else {
                 const StepCore::MetaProperty* p = _object->metaObject()->property(index.row());
@@ -504,7 +506,7 @@ QWidget* PropertiesBrowserDelegate::createEditor(QWidget* parent,
         // XXX: do not use hard-coded pixel sizes
         colorButton->setMinimumWidth(15);
         colorButton->setMaximumWidth(15);
-        connect(colorButton, SIGNAL(changed(const QColor&)), this, SLOT(editorActivated()));
+        connect(colorButton, SIGNAL(changed(QColor)), this, SLOT(editorActivated()));
 
         QHBoxLayout* layout = new QHBoxLayout(editor);
         layout->setContentsMargins(0,0,0,0);
@@ -590,10 +592,10 @@ class PropertiesBrowserView: public QTreeView
 public:
     PropertiesBrowserView(QWidget* parent = 0);
 protected:
-    void changeEvent(QEvent* event);
-    void mousePressEvent(QMouseEvent* event);
-    void drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const;
-    QStyleOptionViewItem viewOptions() const;
+    void changeEvent(QEvent* event) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent* event) Q_DECL_OVERRIDE;
+    void drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QStyleOptionViewItem viewOptions() const Q_DECL_OVERRIDE;
     const int _windowsDecoSize;
     bool _macStyle;
 };
@@ -667,8 +669,8 @@ QStyleOptionViewItem PropertiesBrowserView::viewOptions() const
     return option;
 }
 
-PropertiesBrowser::PropertiesBrowser(WorldModel* worldModel, QWidget* parent, Qt::WindowFlags flags)
-    : QDockWidget(i18n("Properties"), parent, flags)
+PropertiesBrowser::PropertiesBrowser(WorldModel* worldModel, QWidget* parent)
+    : QDockWidget(i18n("Properties"), parent)
 {
     _worldModel = worldModel;
     _propertiesBrowserModel = new PropertiesBrowserModel(worldModel, this);
@@ -689,22 +691,22 @@ PropertiesBrowser::PropertiesBrowser(WorldModel* worldModel, QWidget* parent, Qt
 
     connect(_worldModel, SIGNAL(modelReset()), this, SLOT(worldModelReset()));
     connect(_worldModel, SIGNAL(worldDataChanged(bool)), this, SLOT(worldDataChanged(bool)));
-    connect(_worldModel, SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
-                                this, SLOT(worldRowsRemoved(const QModelIndex&, int, int)));
+    connect(_worldModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                                this, SLOT(worldRowsRemoved(QModelIndex,int,int)));
 
-    connect(_worldModel->selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex&)),
-                                           this, SLOT(worldCurrentChanged(const QModelIndex&, const QModelIndex&)));
+    connect(_worldModel->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+                                           this, SLOT(worldCurrentChanged(QModelIndex,QModelIndex)));
 
-    connect(_treeView->selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex&)),
-                                           this, SLOT(currentChanged(const QModelIndex&, const QModelIndex&)));
+    connect(_treeView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+                                           this, SLOT(currentChanged(QModelIndex,QModelIndex)));
 
-    //connect(_treeView, SIGNAL(doubleClicked(const QModelIndex&)),
-    //                                       this, SLOT(doubleClicked(const QModelIndex&)));
+    //connect(_treeView, SIGNAL(doubleClicked(QModelIndex)),
+    //                                       this, SLOT(doubleClicked(QModelIndex)));
 
-    connect(_propertiesBrowserModel, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-                                           this, SLOT(rowsInserted(const QModelIndex&, int, int)));
-    connect(_propertiesBrowserModel, SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
-                                           this, SLOT(rowsRemoved(const QModelIndex&, int, int)));
+    connect(_propertiesBrowserModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
+                                           this, SLOT(rowsInserted(QModelIndex,int,int)));
+    connect(_propertiesBrowserModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                                           this, SLOT(rowsRemoved(QModelIndex,int,int)));
 
     _treeView->viewport()->installEventFilter(this);
     //_treeView->setMouseTracking(true);
